kenchi\.outlier\_detection\.vmf\_distns module
==============================================

.. automodule:: kenchi.outlier_detection.vmf_distns
    :members:
    :undoc-members:
    :show-inheritance:
